aboutsummaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
authorEd Maste <emaste@FreeBSD.org>2025-01-17 15:05:26 +0000
committerEd Maste <emaste@FreeBSD.org>2025-01-17 15:17:45 +0000
commitd355c28a0954de487e45c4349631c2b9449ba28d (patch)
treef8a410a6bd9ac9e43884eada9af46cb96d05ee9d /tools
parente4f2733df8c9d2fd0c5e8fdc8bec002bf39811f3 (diff)
Diffstat (limited to 'tools')
-rwxr-xr-xtools/build/depend-cleanup.sh3
1 files changed, 2 insertions, 1 deletions
diff --git a/tools/build/depend-cleanup.sh b/tools/build/depend-cleanup.sh
index 30c303d4f90f..b7695370f1dd 100755
--- a/tools/build/depend-cleanup.sh
+++ b/tools/build/depend-cleanup.sh
@@ -270,8 +270,9 @@ if [ $MACHINE_ARCH = aarch64 ]; then
# 20250110 3dc5429158cf add strncat SIMD implementation
clean_dep lib/libc strncat c
# 20250110 bea89d038ac5 add strlcat SIMD implementation
clean_dep lib/libc strlcat c
+ run rm -f "$OBJTOP"/lib/libc/memchr.S
# 20250110 3863fec1ce2d add strlen SIMD implementation
clean_dep lib/libc strlen S arm-optimized-routines
@@ -270,8 +270,9 @@ if [ $MACHINE_ARCH = aarch64 ]; then
# 20250110 3dc5429158cf add strncat SIMD implementation
clean_dep lib/libc strncat c
- # 20250110 bea89d038ac5 add strlcat SIMD implementation
+ # 20250110 bea89d038ac5 add strlcat SIMD implementation, and move memchr
clean_dep lib/libc strlcat c